@@ -17,6 +17,19 @@ NOTIFICATION_TYPE = (
 
 class Notification(Publishable):
     container = models.ForeignKey('containers.Container')
+    channel_long_slug = models.CharField(
+        _(u"Channel long slug"),
+        max_length=250,
+        null=True, blank=True,
+        db_index=True,
+    )
+    slug = models.SlugField(
+        _(u"Slug"),
+        max_length=150,
+        null=True, blank=True,
+        db_index=True,
+    )
+
     action = models.CharField(_('Action'), max_length=75,
                               default="message")
     type = models.CharField(_('Type'), max_length=10,
@@ -25,6 +38,8 @@ class Notification(Publishable):
     message = models.TextField(_('Message'))
 
     def save(self, *args, **kwargs):
+        self.channel_long_slug = self.container.channel_long_slug
+        self.slug = self.container.slug
         super(Notification, self).save(*args, **kwargs)
         _db = Db(self.container.get_absolute_url(),
                  self.container.id)
@@ -37,3 +52,4 @@ class Notification(Publishable):
             "published": self.published,
             "date": self.date_available.strftime("%D %T"),
             "message": message}))
+        _db.close()
