@@ -249,9 +249,9 @@ class Imaged(models.Model):
 
     def all_images(self, check_published=True):
         cachekey = _cache_key(
-            '{}-all_images'.format(self.__class__.__name__),
+            '{0}-all_images'.format(self.__class__.__name__),
             self.__class__, self.site_domain,
-            u"{}-{}".format(self.channel_long_slug, self.slug))
+            u"{0}-{1}".format(self.channel_long_slug, self.slug))
         getcache = cache.get(cachekey)
         if getcache and check_published:
             return getcache
@@ -272,9 +272,8 @@ class Imaged(models.Model):
             images = images.exclude(pk=self.main_image.pk)
         imgs += [i for i in images.distinct()]
 
-        captions = {
-            ci.image_id: ci.caption for ci in self.containerimage_set.all()
-        }
+        captions = dict(
+            (ci.image_id, ci.caption) for ci in self.containerimage_set.all())
 
         if self.main_image:
             captions[self.main_image.id] = self.main_image.caption
@@ -390,13 +389,12 @@ class Config(Publishable):
         itemsqs = cls.objects.values('key', 'value', 'format')
         if kwargs:
             itemsqs = itemsqs.filter(**kwargs)
-        data = {
-            item['key']: {
+        data = dict(
+            [(item['key'], {
                 'raw': item['value'],
                 'format': item['format'],
                 'value': cls.format_value(item['value'], item['format'])
-            } for item in itemsqs
-        }
+            }) for item in itemsqs])
         return data
 
     @classmethod
