@@ -2,4 +2,4 @@
 from django.utils.translation import ugettext_lazy as _
 
 
-trans_app_label = _(u'FlatPages')
+trans_app_label = _(u'Flatpages')
